@@ -71,7 +71,7 @@ class simulation:
         response = requests.request("POST", url, headers=headers, data=payload)
 
     def getStatus(self):
-        url = "https://lexsetapi.azurewebsites.net/api/simulations/getsimulationstatus?id=" + str(self.simID)
+        url = "https://lexsetapi.azurewebsites.net/api/simulations/getstatus?id=" + str(self.simID)
 
         payload={}
         headers = {
